<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function kids_education_pro_body_classes( $classes ) {
	$options = kids_education_pro_get_theme_options();

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	if ( class_exists( 'TP_Education' ) ) {
		$classes[] = is_tp_education() ? 'tp-education' : '';
	}

	// Add a class for typography
	$typography = (  $options['theme_typography'] == 'default' ) ? '' :  $options['theme_typography'];
	$classes[] = esc_attr( $typography );

	// Add a class for layout
	$classes[] = esc_attr( $options['site_layout'] );

	// Add a class for sidebar
	$sidebar_position = kids_education_pro_layout();

	// Add a class for site design
	$classes[] = esc_attr( $options['site_design'] );

	if( is_home() || is_404() ){
		$classes[] = 'no-sidebar';
	}
	elseif ( is_archive() && class_exists( 'TP_Education' ) && is_tp_education() ) {
		$classes[] = 'no-sidebar';
	} 
	elseif ( is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = esc_attr( $sidebar_position );
	} 
	else {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'kids_education_pro_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @param array $classes Classes for the post element.
 * @return array
 */
function kids_education_pro_single_page_class( $classes ) {
    global $post;
    if( is_archive() || is_search() ){
        $classes[] = 'column-wrapper';
    }
    if( is_home() ){
    	 $classes[] = 'blog-item';
    }
    return $classes;
}
add_filter( 'post_class', 'kids_education_pro_single_page_class' );
